==> xlr-server-23.1.8-sources.jar: com/xebialabs/xlrelease/views/TemplateOverview.java <==
package com.xebialabs.xlrelease.views;

import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import com.xebialabs.xlrelease.api.internal.EffectiveSecurity;
import com.xebialabs.xlrelease.serialization.json.jackson.DomainIdDeserializer;
import com.xebialabs.xlrelease.serialization.json.jackson.DomainIdSerializer;

public class TemplateOverview {
    @JsonSerialize(using = DomainIdSerializer.class)
    @JsonDeserialize(using = DomainIdDeserializer.class)
    protected String id;
    protected String type;
    private String status;
    protected String title;
    protected Long plannedDuration;
    private Integer securityUid;
    private EffectiveSecurity security;
    private Integer $scmTraceabilityDataId;


    public String getId() {
        return id;
    }

    public void setId(final String id) {
        this.id = id;
    }

    public String getType() {
        return type;
    }

    public void setType(final String type) {
        this.type = type;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(final String title) {
        this.title = title;
    }

    public Long getPlannedDuration() {
        return plannedDuration;
    }

    public void setPlannedDuration(final Long plannedDuration) {
        this.plannedDuration = plannedDuration;
    }

    public Integer getSecurityUid() {
        return securityUid;
    }

    public void setSecurityUid(final Integer securityUid) {
        this.securityUid = securityUid;
    }

    public EffectiveSecurity getSecurity() {
        return security;
    }

    public void setSecurity(final EffectiveSecurity security) {
        this.security = security;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(final String status) {
        this.status = status;
    }

    public Integer get$scmTraceabilityDataId() {
        return $scmTraceabilityDataId;
    }

    public void set$scmTraceabilityDataId(final Integer $scmTraceabilityDataId) {
        this.$scmTraceabilityDataId = $scmTraceabilityDataId;
    }

}

==> xlr-server-25.3.0-512.1221-sources.jar: com/xebialabs/xlrelease/views/TemplateOverview.java <==
package com.xebialabs.xlrelease.views;

import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import com.xebialabs.xlrelease.api.internal.EffectiveSecurity;
import com.xebialabs.xlrelease.serialization.json.jackson.DomainIdDeserializer;
import com.xebialabs.xlrelease.serialization.json.jackson.DomainIdSerializer;

public class TemplateOverview {
    @JsonSerialize(using = DomainIdSerializer.class)
    @JsonDeserialize(using = DomainIdDeserializer.class)
    private String id;
    private String type;
    private String status;
    private String kind;
    private String title;
    private Long plannedDuration;
    private Long securityUid;
    private EffectiveSecurity security;
    private Long $scmTraceabilityDataId;


    public String getId() {
        return id;
    }

    public void setId(final String id) {
        this.id = id;
    }

    public String getType() {
        return type;
    }

    public void setType(final String type) {
        this.type = type;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(final String status) {
        this.status = status;
    }

    public String getKind() {
        return kind;
    }

    public void setKind(final String kind) {
        this.kind = kind;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(final String title) {
        this.title = title;
    }

    public Long getPlannedDuration() {
        return plannedDuration;
    }

    public void setPlannedDuration(final Long plannedDuration) {
        this.plannedDuration = plannedDuration;
    }

    public Long getSecurityUid() {
        return securityUid;
    }

    public void setSecurityUid(final Long securityUid) {
        this.securityUid = securityUid;
    }

    public EffectiveSecurity getSecurity() {
        return security;
    }

    public void setSecurity(final EffectiveSecurity security) {
        this.security = security;
    }

    public Long get$scmTraceabilityDataId() {
        return $scmTraceabilityDataId;
    }

    public void set$scmTraceabilityDataId(final Long $scmTraceabilityDataId) {
        this.$scmTraceabilityDataId = $scmTraceabilityDataId;
    }

}
